
#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_A8_RLE_ALIGN1
#define LV_ATTRIBUTE_TEST_A8_RLE_ALIGN1
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_A8_RLE_ALIGN1
uint8_t test_A8_RLE_align1_map[] = {

    0x01,0x00,0x00,0x00,0x89,0x0c,0x00,0x00,0xc0,0x12,0x00,0x00,0x47,0xff,0x8b,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x44,0x00,0x8c,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x44,0x00,0x9e,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x1f,0x00,0x11,0xff,0xff,0x00,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x3f,0x96,0xd6,0xf9,0xf9,0xd6,0x96,0x3f,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x1a,0x93,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x93,0xff,0x1a,
    0x00,0x00,0x00,0x00,0x00,0x00,0x6a,0xdf,0xdf,0x6a,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0xff,
    0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0x00,0x1a,0xa7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa7,
    0x1a,0x00,0x00,0x00,0x00,0x00,0xdf,0xff,0xff,0xdf,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0x93,0x00,0x00,0x00,0x00,0x00,0xdf,0xff,0xff,0xdf,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0xff,0x00,
    0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0x00,0x00,0x00,0x3f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0x3f,0x00,0x00,0x00,0x00,0x6a,0xdf,0xdf,0x6a,0x00,0x00,0x00,0xff,0x00,
    0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0x00,0x00,0x00,0x96,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0x96,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0xff,0xff,0xff,0xff,0x00,0xff,0x00,0xff,
    0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0x00,0x00,0x00,0xd6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xd6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0x00,0x00,0x00,0xf9,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xf9,0x00,0x00,0x00,0x40,0xac,0xf2,0xf2,0xac,0x40,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0xff,
    0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0x00,0x00,0x00,0xf9,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xf9,0x00,0x00,0x40,0xd3,0xff,0xff,0xff,0xff,0xd3,0x40,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0x00,0x00,0x00,0xd6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xd6,0x00,0x00,0xac,0xff,0xff,0xff,0xff,0xff,0xff,
    0xac,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0xff,0xff,0xff,0xff,0xff,0x00,
    0xff,0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x96,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0x96,0x00,0x00,0xf2,0xff,0xff,0xff,0xff,0xff,0xff,
    0xf2,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x3f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x3f,0x00,0x00,0xf2,0xff,0xff,0xff,0xff,0xff,
    0xff,0xf2,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0x93,0x00,0x00,0x00,0xac,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xac,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x1a,0xa7,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xa7,0x1a,0x00,0x00,0x00,0x40,0xd3,0xff,0xff,0xff,
    0xff,0xd3,0x40,0x00,0x00,0x00,0xff,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xc7,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x1a,0x93,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0x93,0x1a,0x00,0x00,0x00,0x00,0x00,0x40,0xac,0xf2,
    0xf2,0xac,0x40,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x18,0x00,0xb8,0x3f,0x96,0xd6,0xf9,0xf9,0xd6,0x96,
    0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x44,0x00,0x8c,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x44,0x00,0xa0,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x12,0x28,0x33,0x26,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x2e,0xff,0x9d,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x35,0x95,0xdd,0xff,0xff,0xff,0xff,0xfa,0xc4,
    0x5c,0x01,0x00,0x35,0x00,0x9c,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xb2,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xbb,
    0x0b,0x00,0x34,0x00,0x9c,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0xe9,0xff,0xff,0xff,0xff,0xfe,0xfa,0xff,0xff,0xff,0xff,0xff,0xa9,
    0x00,0x34,0x00,0x9d,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xe5,0xff,0xff,0xe5,0x49,0x09,0x03,0x3c,0xdd,0xff,0xff,0xff,0xff,0x2b,
    0x00,0x33,0x00,0xad,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xe1,0xff,0xff,0xa3,0x00,0x00,0x00,0x00,0x44,0xff,0xff,0xff,0xff,0x6f,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x76,0xbb,0xdd,0xe6,0xd3,0x9e,0x37,
    0x00,0x23,0x00,0xae,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xbe,0xdc,0xdc,0x6b,0x00,0x00,0x00,0x00,0x09,0xff,0xff,0xff,0xff,0x89,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x53,0xf8,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,
    0x7b,0x00,0x22,0x00,0xaf,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x14,0x14,0xff,0xff,0xff,0xff,
    0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0xff,0xff,0xe0,0x8b,0x83,0xda,0xff,
    0xff,0xff,0x37,0x00,0x21,0x00,0xaf,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0x00,0x01,0x52,0xa3,0xe2,0xfa,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0x40,0x00,0x00,
    0x13,0xf1,0xff,0xff,0x8c,0x00,0x14,0x00,0xbc,0xff,0x00,0xff,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x1d,0xca,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xa4,0xa4,0x12,0x00,0x00,0x00,
    0xc5,0xff,0xff,0xa8,0x00,0x21,0x00,0xbc,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x0d,0xdd,0xff,0xff,0xff,0xff,0xe7,0xc1,0xb8,0xb8,0xff,
    0xff,0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x55,0x7a,
    0x8c,0x90,0xe4,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x5e,
    0x7e,0x6c,0x1e,0x00,0x14,0x00,0xbd,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0x79,0xff,0xff,0xff,0xff,0x79,0x03,0x00,0x00,0x00,0xff,0xff,
    0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x81,0xf7,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0xf7,0xfe,0xe1,
    0xfc,0xf9,0x42,0x00,0x13,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0xbb,0xff,0xff,0xff,0xd4,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0xff,0xff,0xff,0xbc,0x8d,
    0x88,0xe2,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0xff,0x7e,0x00,
    0x5d,0xff,0xb4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0xff,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0xd1,0xff,0xff,0xff,0xc8,0x00,0x00,0x00,0x00,0x2a,0xff,0xff,
    0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xf3,0xff,0xff,0x8e,0x00,0x00,
    0x00,0xc0,0xff,0xff,0xac,0x00,0x8e,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x22,0x49,
    0x61,0x84,0xff,0xcf,0x00,0x13,0x00,0xbd,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0xb5,0xff,0xff,0xff,0xff,0x70,0x18,0x1f,0x6c,0xec,0xff,
    0xff,0xff,0xff,0x94,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xff,0xff,0x56,0x00,
    0x00,0x03,0xd4,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xcc,0xff,
    0xde,0xd9,0xff,0xd0,0x00,0x13,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x64,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xfb,0xdc,0x4c,0x00,0x00,0x00,0x00,0x07,0xf7,0xff,0xff,0xd4,0x58,
    0x5f,0xc5,0xff,0xff,0xff,0xc1,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0xff,0xa4,
    0x00,0x30,0xff,0xd0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x04,0xc2,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb3,0xc5,
    0xff,0xff,0xff,0xff,0xff,0x64,0x00,0x00,0x00,0x00,0x00,0x95,0xff,0xff,0xff,0xff,
    0xff,0xff,0xe1,0xff,0xff,0xff,0xff,0x8f,0x0c,0x00,0x00,0x00,0x00,0x00,0x64,0xff,
    0xd5,0x64,0xbe,0xff,0xdf,0x26,0x00,0x12,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x0a,0x92,0xf6,0xff,0xff,0xff,0xf3,0x83,
    0x05,0x72,0xff,0xff,0xff,0xff,0xff,0x64,0x00,0x00,0x00,0x00,0x00,0x07,0x97,0xfa,
    0xff,0xff,0xeb,0x5c,0x60,0xff,0xff,0xff,0xff,0x0c,0x00,0x00,0x00,0x00,0x00,0x09,
    0xbc,0xff,0xfb,0x83,0xf9,0xff,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x0a,0x3b,0x4e,0x3c,0x0b,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,
    0x37,0x31,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x8b,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x14,0x0f,0x00,0x16,0x00,0x8c,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x44,0x00,0x8e,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xe9,0xe1,0xd9,0xd0,0xc7,0xbf,
    0xb6,0xae,0xa5,0x9d,0x94,0x8c,0x83,0x7a,0x71,0x69,0x60,0x58,0x4f,0x47,0x3e,0x36,
    0x2d,0x25,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xea,0xe1,0xd8,
    0xd0,0xc8,0xbe,0xb6,0xae,0xa5,0x9d,0x94,0x8b,0x83,0x7a,0x72,0x69,0x60,0x58,0x50,
    0x47,0x3e,0x35,0x2d,0x25,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,
    0xe9,0xe1,0xd8,0xd0,0xc7,0xbe,0xb6,0xad,0xa5,0x9c,0x94,0x8b,0x83,0x7a,0x72,0x69,
    0x60,0x58,0x4f,0x47,0x3e,0x36,0x2d,0x24,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,
    0xb0,0xfa,0xf3,0xea,0xe1,0xd8,0xd0,0xc7,0xbe,0xb6,0xae,0xa5,0x9d,0x94,0x8b,0x82,
    0x7a,0x72,0x69,0x60,0x58,0x50,0x47,0x3e,0x35,0x2d,0x24,0x1c,0x14,0x0b,0x02,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0xff,0x20,0xff,0xb0,0xfb,0xf2,0xea,0xe1,0xd8,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9d,
    0x94,0x8b,0x82,0x7a,0x72,0x69,0x60,0x58,0x4f,0x47,0x3e,0x35,0x2d,0x25,0x1c,0x13,
    0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xea,0xe1,0xd8,0xd0,0xc7,0xbf,0xb6,
    0xad,0xa5,0x9d,0x94,0x8b,0x83,0x7a,0x71,0x69,0x61,0x58,0x4f,0x47,0x3e,0x36,0x2d,
    0x25,0x1c,0x13,0x0a,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xe9,0xe1,0xd9,0xd0,
    0xc7,0xbf,0xb6,0xad,0xa5,0x9d,0x94,0x8c,0x82,0x7a,0x72,0x69,0x61,0x58,0x4f,0x47,
    0x3e,0x36,0x2d,0x25,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xe9,
    0xe1,0xd9,0xd0,0xc8,0xbe,0xb6,0xad,0xa5,0x9c,0x94,0x8b,0x83,0x7a,0x72,0x69,0x61,
    0x58,0x4f,0x47,0x3e,0x36,0x2d,0x24,0x1c,0x14,0x0a,0x03,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,
    0xfb,0xf2,0xea,0xe1,0xd9,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9c,0x94,0x8c,0x83,0x7a,
    0x72,0x69,0x61,0x58,0x4f,0x47,0x3e,0x36,0x2d,0x25,0x1c,0x13,0x0b,0x02,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,
    0x20,0xff,0xb0,0xfa,0xf2,0xea,0xe1,0xd9,0xcf,0xc7,0xbf,0xb6,0xae,0xa5,0x9c,0x94,
    0x8b,0x83,0x7a,0x71,0x69,0x61,0x58,0x4f,0x46,0x3e,0x35,0x2d,0x24,0x1c,0x13,0x0a,
    0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0xff,0x20,0xff,0xb0,0xfa,0xf2,0xe9,0xe1,0xd9,0xd0,0xc7,0xbf,0xb6,0xae,
    0xa5,0x9d,0x94,0x8b,0x82,0x7a,0x72,0x69,0x60,0x58,0x4f,0x46,0x3f,0x35,0x2d,0x24,
    0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfb,0xf2,0xe9,0xe1,0xd8,0xd0,0xc7,
    0xbf,0xb6,0xad,0xa5,0x9d,0x93,0x8c,0x83,0x7a,0x72,0x69,0x60,0x58,0x50,0x46,0x3e,
    0x36,0x2d,0x24,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xb0,0xfa,0xf2,0xea,0xe1,
    0xd8,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9d,0x94,0x8c,0x83,0x7a,0x72,0x69,0x61,0x58,
    0x4f,0x47,0x3e,0x36,0x2d,0x24,0x1c,0x13,0x0b,0x02,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0x20,0xff,0xae,0xfb,
    0xf2,0xea,0xe1,0xd9,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9c,0x94,0x8c,0x83,0x7a,0x72,
    0x69,0x60,0x57,0x50,0x47,0x3f,0x36,0x2d,0x24,0x1c,0x13,0x0a,0x02,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x44,0x00,0x8c,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x44,0x00,0x8c,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x44,0x00,0x8b,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x46,0xff,0x89,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_A8_RLE_align1 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_A8,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 80,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_A8_RLE_align1_map),
  .data = test_A8_RLE_align1_map,
  .reserved = NULL,
};

